///////////////////////////////////////////////////////////////////////////////////////////////////
//         glibPlatformException.h
///////////////////////////////////////////////////////////////////////////////////////////////////

/*! \class        glibPlatformException.h
*  \brief        <brief description> 
*                <long description> 
*  \version      1.0 
*  \date         15.12.2004
*  \author       responsible: [kt]
*/


/*--------------------------------------------------------------------------------------------------

This is a working example of a ListGen configuration section. It defines the lists (one list in this
case), the files (NOTE: this file, namely 'glibPlatformException.h' must also be listed. Otherwise
all the other sections will not be processed) and the substitution patterns.


$$%%$$%%conf>>>> lists.conf

	@begin_list 
		exceptions
	@end_list

	@begin_files
		glibPlatformException.h
		glibPlatformException.cpp
	@end_files

	@begin_patterns: exceptions

		@pattern:	norm	enum	 	1	$// @0 WIN32-exception-code: @1\n\i,     
		@pattern:	last	enum	 	1	$// @0 WIN32-exception-code: @1\n\i      
		@pattern:	n_norm	enum	 	1	$// @0 WIN32-exception-code: @1\n\i = #, 
		@pattern:	n_last	enum	 	1	$// @0 WIN32-exception-code: @1\n\i = #  

		@pattern: 	norm	win2glib 	1	$case @1: return ; break;
		@pattern: 	last	win2glib 	1	$case @1: return ; break;
		@pattern: 	n_norm	win2glib 	1	$case @1: return ; break;
		@pattern: 	n_last	win2glib 	1	$case @1: return ; break;

		@pattern:   norm	glib2win 	1	$case : \n\i\treturn @1; \n\i\tbreak; 
		@pattern:   last	glib2win 	1	$case : \n\i\treturn @1; \n\i\tbreak;
		@pattern:   n_norm	glib2win 	1	$case : \n\i\treturn @1; \n\i\tbreak;
		@pattern:   n_last	glib2win 	1	$case : \n\i\treturn @1; \n\i\tbreak;

		@pattern:   norm	tostring 	1	$case :return "@0";
		@pattern:   last	tostring 	1	$case :return "@0";
		@pattern:   n_norm	tostring 	1	$case :return "@0";
		@pattern:   n_last	tostring 	1	$case :return "@0";

	@end_patterns

$$%%$$%%conf<<<<

This is a ListGen list declaration. It defines the content of the list, which can be substituted at
different places in the code with different formatting, according to the specified patterns.

It you have to maintain the list, then do it HERE ! That's what ListGen is for.

$$%%$$%%list>>>> exceptions

$ Special purpose

	 special
		
		# -3	
		glibExcepionType_UNKNOWN							unknown exception.																		0xffffffff
		glibExcepionType_Reraised							Exception was thrown again after being handled.											0xe1000001
		glibExcepionType_MS_VCPP_THROW						A Microsoft Visual c++ Exception was thrown using throw(), but not basically handled.	0xe06d7363

$ Hardware exceptions

	 Memory

		# 0

		glibExcepionType_MEM_AccessViolation				Memory access violation.																STATUS_ACCESS_VIOLATION
		glibExcepionType_MEM_MisalignedAccess				Memory Misaligned Access.																STATUS_DATATYPE_MISALIGNMENT
		
		
	 Arithmetic		
		
		glibExcepionType_ARITH_DivisionByZero				ARITHMETIC: Division by Zero.															STATUS_INTEGER_DIVIDE_BY_ZERO
		glibExcepionType_ARITH_Overflow						ARITHMETIC: Overflow.																	STATUS_INTEGER_OVERFLOW
		
	 Instruction set		
		
		glibExcepionType_CPU_IllegalInstruction				CPU: Illegal instruction.																STATUS_ILLEGAL_INSTRUCTION
		glibExcepionType_CPU_PrivilegedInstruction			CPU: Privileged Instruction.															STATUS_PRIVILEGED_INSTRUCTION
		
	 Debugging		
		
		glibExcepionType_DEBUG_Breakpoint					DEBUG: Breakpoint hit (inline interrupt ??).											STATUS_BREAKPOINT
		glibExcepionType_DEBUG_Singlestep					DEBUG: Single step instruction.															STATUS_SINGLE_STEP
		
$ Glibs		
	
	 Memory
		
		glibExcepionType_GLIB_MEM_OutOfMemory				GLIBS[GEN]: Out Of Memory.																0xe1000002
		glibExcepionType_GLIB_MEM_NullpointerAtDelete		GLIBS[GEN]: Null pointer specified at delete.											0xe1000003
		glibExcepionType_GLIB_MEM_ConstructionOfNullObj		GLIBS[GEN]: Construction of NULL Object.												0xe1000004
		glibExcepionType_GLIB_MEM_DeletingNullObj			GLIBS[GEN]: Deletation of NULL Object.													0xe1000005
		glibExcepionType_GLIB_MEM_WrongAlignment			GLIBS[GEN]: Wrong alignment specified for memblock. Must be power of 2 from 1 to 256.	0xe1000006
		glibExcepionType_GLIB_MEM_MemCategoryNotLocked		GLIBS[GEN]: Memory categories was not locked during statistics access.					0xe1000007
		glibExcepionType_GLIB_MEM_FileInfoStackOverflow		GLIBS[GEN]: Overflow of file info stack (mem logging). Increase GLIB_MEM_MAX_FILEINFO_STACK_SIZE !		0xe1000008
		glibExcepionType_GLIB_MEM_FileInfoStackUnderflow	GLIBS[GEN]: Underflow of file info stack (mem logging).									0xe1000009

	 Thread management		
		
		glibExcepionType_GLIB_THREAD_IllegalThreadId		GLIBS[THREAD]: Illegal Thread Id.														0xe2000001
		glibExcepionType_GLIB_THREAD_NoMutex				GLIBS[THREAD]: Mutex in Thread Manager missing.											0xe2000002
		glibExcepionType_GLIB_THREAD_InterfaceMissing		GLIBS[THREAD]: Interface missing for thread. Cannot run.								0xe2000003
		
	 Logger		
		
		glibExcepionType_GLIB_LOGGER_IllegalCall			GLIBS[LOGGER]: Illegal call. Unregistered Thread May not call Logging function.			0xe4000001
		glibExcepionType_GLIB_LOGGER_ContextNotFound		GLIBS[LOGGER]: Logging context was not found.											0xe4000002		
		glibExcepionType_GLIB_LOGGER_ContextStackOverflow	GLIBS[LOGGER]: Logging stack overflow.													0xe4000003
		glibExcepionType_GLIB_LOGGER_ContextStackUnderflow	GLIBS[LOGGER]: Logging stack underflow.													0xe4000004
		
	 Debugging		
		
		glibExcepionType_GLIB_DEBUG_AssertionFailed			GLIBS[DEBUG]: Assertion Failed.															0xe5000001
		glibExcepionType_GLIB_DEBUG_Error					GLIBS[DEBUG]: General Error.															0xe5000002
		glibExcepionType_GLIB_DEBUG_Warning					GLIBS[DEBUG]: General Warning.															0xe5000003
		glibExcepionType_GLIB_DEBUG_Info					GLIBS[DEBUG]: General Info.																0xe5000004
		glibExcepionType_GLIB_DEBUG_Note					GLIBS[DEBUG]: General Note.																0xe5000005
		glibExcepionType_GLIB_DEBUG_Message					GLIBS[DEBUG]: General Message.															0xe5000006
		glibExcepionType_GLIB_DEBUG_FailAssert				GLIBS[DEBUG]: Assertion Failed.															0xe5000007
		
	 File System		
		
		glibExcepionType_GLIB_FILE_CannotOpen				GLIBS[FILE]: Unable to open file.														0xe6000001
		glibExcepionType_GLIB_FILE_UnexceptedEnd			GLIBS[FILE]: Unexpecet end of file.														0xe6000002
		glibExcepionType_GLIB_FILE_FormatError				GLIBS[FILE]: Wrong file Format.															0xe6000003
		
	 Parser		
		
		glibExcepionType_GLIB_PARSE_Error					GLIBS[PARSE]: General parsing error.													0xe7000001
		glibExcepionType_GLIB_PARSE_Warning					GLIBS[PARSE]: Fatal parsing warning.													0xe7000002
		glibExcepionType_GLIB_PARSE_BadFormat				GLIBS[PARSE]: Bad Format.																0xe7000003
		glibExcepionType_GLIB_PARSE_BadTag					GLIBS[PARSE]: Bad Tag.																	0xe7000004
		glibExcepionType_GLIB_PARSE_BadCode					GLIBS[PARSE]: Bad Code.																	0xe7000005
		glibExcepionType_GLIB_PARSE_VersionMismatch			GLIBS[PARSE]: Version Mismatch.															0xe7000006
		glibExcepionType_GLIB_PARSE_EndianMismatch			GLIBS[PARSE]: Endian Mismatch.															0xe7000007
		glibExcepionType_GLIB_PARSE_Accessrights			GLIBS[PARSE]: Accessright Exception.													0xe7000008
		glibExcepionType_GLIB_PARSE_WrongPassword			GLIBS[PARSE]: Wrong password.															0xe7000009
		
	 Kernel		
		
		glibExcepionType_GLIB_KERNEL_GeneralTrouble			GLIBS[KERNEL]: General Kernel Trouble.													0xe8000001
		glibExcepionType_GLIB_KERNEL_WindowsSuxx			GLIBS[KERNEL]: M$ WINDOOF SUXX Exception (Windows version of OsTrouble Exception).		0xe8000002
		glibExcepionType_GLIB_KERNEL_OSTrouble				GLIBS[KERNEL]: Os Trouble Exception.													0xe8000003
		glibExcepionType_GLIB_KERNEL_ConfigfileNotFound		GLIBS[KERNEL]: Kernel Config file missing.												0xe8000004
		glibExcepionType_GLIB_KERNEL_MutexNotFound			GLIBS[KERNEL]: Mutex was missing.														0xe8000005
		glibExcepionType_GLIB_KERNEL_MutexNotAllocatable	GLIBS[KERNEL]: Could not allocate Mutex.												0xe8000006
		--
		glibExcepionType_GLIB_KERNEL_TooManyLogClasses		GLIBS[KERNEL]: Too many logger classes are specified. Maximum is 16.					0xe8000007
		glibExcepionType_GLIB_KERNEL_TooManyLogDrains		GLIBS[KERNEL]: Too many log drains are specified. Maximum is 16.						0xe8000008
		glibExcepionType_GLIB_KERNEL_IdentifierTooLong		GLIBS[KERNEL]: A used name identifier was too long. Max is normally 15 or 31.			0xe8000009
		glibExcepionType_GLIB_KERNEL_LogDrainClassNotFound	GLIBS[KERNEL]: A specified logging drain class (in glibs.config) was not found. 		0xe800000a
		--
		glibExcepionType_GLIB_KERNEL_OutOfMemory			GLIBS[KERNEL]: Out of Memory Exception.													0xe800000b

	 Plugin manager		
		
		glibExcepionType_GLIB_PLUGINS_UnknownIdentifier		GLIBS[PLUGIN]: Factory class Identifier unknown.										0xe9000001
		glibExcepionType_GLIB_PLUGINS_ClusterNotFound		GLIBS[PLUGIN]: Could not locate plaugi cluster for class.								0xe9000002
		glibExcepionType_GLIB_PLUGINS_PluginNotFound		GLIBS[PLUGIN]: Plugin for class identifier not found.									0xe9000003
		glibExcepionType_GLIB_PLUGINS_MinimumCriteria		GLIBS[PLUGIN]: No Plugin which meets the minimum criteria of System.					0xe9000004
		glibExcepionType_GLIB_PLUGINS_MaximumCriteria		GLIBS[PLUGIN]: No Plugin which meets the required minimum criteria.						0xe9000005
		glibExcepionType_GLIB_PLUGINS_FileNotFound			GLIBS[PLUGIN]: Plugin file (*.library or *.dll) not found.								0xe9000006
		glibExcepionType_GLIB_PLUGINS_LoadError				GLIBS[PLUGIN]: Plugin was found, but could not be loaded. Check dependencies !			0xe9000007

	 Platform

		glibExcepionType_GLIB_PLATFORM_IntervalTimer		GLIBS[PLATFORM]: General interval timer exception (Assert replacement).					0xeb000001
		glibExcepionType_GLIB_PLATFORM_NoRunnableInterface	GLIBS[PLATFORM]: Runnable interface is NULL. Need interface to run thread.				0xeb000002

$$%%$$%%list<<<<

----------------------------------------------------------------------------------------------------*/



/*!  \enum         enum glibExcepionType 
*    \file         glibPlatformException.h
*    \brief        <brief description> 
*                  <long description> 
*/
enum glibExcepionType {


	// This is an automatically generated region. All lines between the pattern start tag and the 
	// pattern end tag will be removed and rewritten each time ListGen processes this file.

	// WARNING !!!! DON't put important code within these tags. It will be lost as soon ListGen will
	// be started.

	//$$%%$$%%pattern>>>> exceptions enum 
	//---------------------------------------------------------------------------------------------
	// Section: Special purpose  
	//---------------------------------------------------------------------------------------------

	// special  
	// unknown exception. WIN32-exception-code: 0xffffffff 
	glibExcepionType_UNKNOWN = -3,  
	// Exception was thrown again after being handled. WIN32-exception-code: 0xe1000001 
	glibExcepionType_Reraised,      
	// A Microsoft Visual c++ Exception was thrown using throw(), but not basically handled. WIN32-exception-code: 0xe06d7363 
	glibExcepionType_MS_VCPP_THROW,      


	//---------------------------------------------------------------------------------------------
	// Section: Hardware exceptions  
	//---------------------------------------------------------------------------------------------

	// Memory  
	// Memory access violation. WIN32-exception-code: STATUS_ACCESS_VIOLATION 
	glibExcepionType_MEM_AccessViolation = 0,  
	// Memory Misaligned Access. WIN32-exception-code: STATUS_DATATYPE_MISALIGNMENT 
	glibExcepionType_MEM_MisalignedAccess,      


	// Arithmetic		  
	// ARITHMETIC: Division by Zero. WIN32-exception-code: STATUS_INTEGER_DIVIDE_BY_ZERO 
	glibExcepionType_ARITH_DivisionByZero,      
	// ARITHMETIC: Overflow. WIN32-exception-code: STATUS_INTEGER_OVERFLOW 
	glibExcepionType_ARITH_Overflow,      


	// Instruction set		  
	// CPU: Illegal instruction. WIN32-exception-code: STATUS_ILLEGAL_INSTRUCTION 
	glibExcepionType_CPU_IllegalInstruction,      
	// CPU: Privileged Instruction. WIN32-exception-code: STATUS_PRIVILEGED_INSTRUCTION 
	glibExcepionType_CPU_PrivilegedInstruction,      


	// Debugging		  
	// DEBUG: Breakpoint hit (inline interrupt ??). WIN32-exception-code: STATUS_BREAKPOINT 
	glibExcepionType_DEBUG_Breakpoint,      
	// DEBUG: Single step instruction. WIN32-exception-code: STATUS_SINGLE_STEP 
	glibExcepionType_DEBUG_Singlestep,      


	//---------------------------------------------------------------------------------------------
	// Section: Glibs		  
	//---------------------------------------------------------------------------------------------

	// Memory  
	// GLIBS[GEN]: Out Of Memory. WIN32-exception-code: 0xe1000002 
	glibExcepionType_GLIB_MEM_OutOfMemory,      
	// GLIBS[GEN]: Null pointer specified at delete. WIN32-exception-code: 0xe1000003 
	glibExcepionType_GLIB_MEM_NullpointerAtDelete,      
	// GLIBS[GEN]: Construction of NULL Object. WIN32-exception-code: 0xe1000004 
	glibExcepionType_GLIB_MEM_ConstructionOfNullObj,      
	// GLIBS[GEN]: Deletation of NULL Object. WIN32-exception-code: 0xe1000005 
	glibExcepionType_GLIB_MEM_DeletingNullObj,      
	// GLIBS[GEN]: Wrong alignment specified for memblock. Must be power of 2 from 1 to 256. WIN32-exception-code: 0xe1000006 
	glibExcepionType_GLIB_MEM_WrongAlignment,      
	// GLIBS[GEN]: Memory categories was not locked during statistics access. WIN32-exception-code: 0xe1000007 
	glibExcepionType_GLIB_MEM_MemCategoryNotLocked,      
	// GLIBS[GEN]: Overflow of file info stack (mem logging). Increase GLIB_MEM_MAX_FILEINFO_STACK_SIZE ! WIN32-exception-code: 0xe1000008 
	glibExcepionType_GLIB_MEM_FileInfoStackOverflow,      
	// GLIBS[GEN]: Underflow of file info stack (mem logging). WIN32-exception-code: 0xe1000009 
	glibExcepionType_GLIB_MEM_FileInfoStackUnderflow,      


	// Thread management		  
	// GLIBS[THREAD]: Illegal Thread Id. WIN32-exception-code: 0xe2000001 
	glibExcepionType_GLIB_THREAD_IllegalThreadId,      
	// GLIBS[THREAD]: Mutex in Thread Manager missing. WIN32-exception-code: 0xe2000002 
	glibExcepionType_GLIB_THREAD_NoMutex,      
	// GLIBS[THREAD]: Interface missing for thread. Cannot run. WIN32-exception-code: 0xe2000003 
	glibExcepionType_GLIB_THREAD_InterfaceMissing,      


	// Logger		  
	// GLIBS[LOGGER]: Illegal call. Unregistered Thread May not call Logging function. WIN32-exception-code: 0xe4000001 
	glibExcepionType_GLIB_LOGGER_IllegalCall,      
	// GLIBS[LOGGER]: Logging context was not found. WIN32-exception-code: 0xe4000002
	glibExcepionType_GLIB_LOGGER_ContextNotFound,      
	// GLIBS[LOGGER]: Logging stack overflow. WIN32-exception-code: 0xe4000003 
	glibExcepionType_GLIB_LOGGER_ContextStackOverflow,      
	// GLIBS[LOGGER]: Logging stack underflow. WIN32-exception-code: 0xe4000004 
	glibExcepionType_GLIB_LOGGER_ContextStackUnderflow,      


	// Debugging		  
	// GLIBS[DEBUG]: Assertion Failed. WIN32-exception-code: 0xe5000001 
	glibExcepionType_GLIB_DEBUG_AssertionFailed,      
	// GLIBS[DEBUG]: General Error. WIN32-exception-code: 0xe5000002 
	glibExcepionType_GLIB_DEBUG_Error,      
	// GLIBS[DEBUG]: General Warning. WIN32-exception-code: 0xe5000003 
	glibExcepionType_GLIB_DEBUG_Warning,      
	// GLIBS[DEBUG]: General Info. WIN32-exception-code: 0xe5000004 
	glibExcepionType_GLIB_DEBUG_Info,      
	// GLIBS[DEBUG]: General Note. WIN32-exception-code: 0xe5000005 
	glibExcepionType_GLIB_DEBUG_Note,      
	// GLIBS[DEBUG]: General Message. WIN32-exception-code: 0xe5000006 
	glibExcepionType_GLIB_DEBUG_Message,      
	// GLIBS[DEBUG]: Assertion Failed. WIN32-exception-code: 0xe5000007 
	glibExcepionType_GLIB_DEBUG_FailAssert,      


	// File System		  
	// GLIBS[FILE]: Unable to open file. WIN32-exception-code: 0xe6000001 
	glibExcepionType_GLIB_FILE_CannotOpen,      
	// GLIBS[FILE]: Unexpecet end of file. WIN32-exception-code: 0xe6000002 
	glibExcepionType_GLIB_FILE_UnexceptedEnd,      
	// GLIBS[FILE]: Wrong file Format. WIN32-exception-code: 0xe6000003 
	glibExcepionType_GLIB_FILE_FormatError,      


	// Parser		  
	// GLIBS[PARSE]: General parsing error. WIN32-exception-code: 0xe7000001 
	glibExcepionType_GLIB_PARSE_Error,      
	// GLIBS[PARSE]: Fatal parsing warning. WIN32-exception-code: 0xe7000002 
	glibExcepionType_GLIB_PARSE_Warning,      
	// GLIBS[PARSE]: Bad Format. WIN32-exception-code: 0xe7000003 
	glibExcepionType_GLIB_PARSE_BadFormat,      
	// GLIBS[PARSE]: Bad Tag. WIN32-exception-code: 0xe7000004 
	glibExcepionType_GLIB_PARSE_BadTag,      
	// GLIBS[PARSE]: Bad Code. WIN32-exception-code: 0xe7000005 
	glibExcepionType_GLIB_PARSE_BadCode,      
	// GLIBS[PARSE]: Version Mismatch. WIN32-exception-code: 0xe7000006 
	glibExcepionType_GLIB_PARSE_VersionMismatch,      
	// GLIBS[PARSE]: Endian Mismatch. WIN32-exception-code: 0xe7000007 
	glibExcepionType_GLIB_PARSE_EndianMismatch,      
	// GLIBS[PARSE]: Accessright Exception. WIN32-exception-code: 0xe7000008 
	glibExcepionType_GLIB_PARSE_Accessrights,      
	// GLIBS[PARSE]: Wrong password. WIN32-exception-code: 0xe7000009 
	glibExcepionType_GLIB_PARSE_WrongPassword,      


	// Kernel		  
	// GLIBS[KERNEL]: General Kernel Trouble. WIN32-exception-code: 0xe8000001 
	glibExcepionType_GLIB_KERNEL_GeneralTrouble,      
	// GLIBS[KERNEL]: M$ WINDOOF SUXX Exception (Windows version of OsTrouble Exception). WIN32-exception-code: 0xe8000002 
	glibExcepionType_GLIB_KERNEL_WindowsSuxx,      
	// GLIBS[KERNEL]: Os Trouble Exception. WIN32-exception-code: 0xe8000003 
	glibExcepionType_GLIB_KERNEL_OSTrouble,      
	// GLIBS[KERNEL]: Kernel Config file missing. WIN32-exception-code: 0xe8000004 
	glibExcepionType_GLIB_KERNEL_ConfigfileNotFound,      
	// GLIBS[KERNEL]: Mutex was missing. WIN32-exception-code: 0xe8000005 
	glibExcepionType_GLIB_KERNEL_MutexNotFound,      
	// GLIBS[KERNEL]: Could not allocate Mutex. WIN32-exception-code: 0xe8000006 
	glibExcepionType_GLIB_KERNEL_MutexNotAllocatable,      

	// GLIBS[KERNEL]: Too many logger classes are specified. Maximum is 16. WIN32-exception-code: 0xe8000007 
	glibExcepionType_GLIB_KERNEL_TooManyLogClasses,      
	// GLIBS[KERNEL]: Too many log drains are specified. Maximum is 16. WIN32-exception-code: 0xe8000008 
	glibExcepionType_GLIB_KERNEL_TooManyLogDrains,      
	// GLIBS[KERNEL]: A used name identifier was too long. Max is normally 15 or 31. WIN32-exception-code: 0xe8000009 
	glibExcepionType_GLIB_KERNEL_IdentifierTooLong,      
	// GLIBS[KERNEL]: A specified logging drain class (in glibs.config) was not found.  WIN32-exception-code: 0xe800000a 
	glibExcepionType_GLIB_KERNEL_LogDrainClassNotFound,      

	// GLIBS[KERNEL]: Out of Memory Exception. WIN32-exception-code: 0xe800000b 
	glibExcepionType_GLIB_KERNEL_OutOfMemory,      


	// Plugin manager		  
	// GLIBS[PLUGIN]: Factory class Identifier unknown. WIN32-exception-code: 0xe9000001 
	glibExcepionType_GLIB_PLUGINS_UnknownIdentifier,      
	// GLIBS[PLUGIN]: Could not locate plaugi cluster for class. WIN32-exception-code: 0xe9000002 
	glibExcepionType_GLIB_PLUGINS_ClusterNotFound,      
	// GLIBS[PLUGIN]: Plugin for class identifier not found. WIN32-exception-code: 0xe9000003 
	glibExcepionType_GLIB_PLUGINS_PluginNotFound,      
	// GLIBS[PLUGIN]: No Plugin which meets the minimum criteria of System. WIN32-exception-code: 0xe9000004 
	glibExcepionType_GLIB_PLUGINS_MinimumCriteria,      
	// GLIBS[PLUGIN]: No Plugin which meets the required minimum criteria. WIN32-exception-code: 0xe9000005 
	glibExcepionType_GLIB_PLUGINS_MaximumCriteria,      
	// GLIBS[PLUGIN]: Plugin file (*.library or *.dll) not found. WIN32-exception-code: 0xe9000006 
	glibExcepionType_GLIB_PLUGINS_FileNotFound,      
	// GLIBS[PLUGIN]: Plugin was found, but could not be loaded. Check dependencies ! WIN32-exception-code: 0xe9000007 
	glibExcepionType_GLIB_PLUGINS_LoadError,      


	// Platform  
	// GLIBS[PLATFORM]: General interval timer exception (Assert replacement). WIN32-exception-code: 0xeb000001 
	glibExcepionType_GLIB_PLATFORM_IntervalTimer,      
	// GLIBS[PLATFORM]: Runnable interface is NULL. Need interface to run thread. WIN32-exception-code: 0xeb000002 
	glibExcepionType_GLIB_PLATFORM_NoRunnableInterface       


	//$$%%$$%%pattern<<<< 
};
